@@ -12,24 +12,32 @@ from libreflow_launcher.view import MainWindow
 
 
 class SessionApp(QtWidgets.QApplication):
-
     def __init__(self, argv):
         super(SessionApp, self).__init__(argv)
         self.setApplicationName("Libreflow Launcher")
 
         self.parse_command_line_args(argv)
 
-        QtGui.QFontDatabase.addApplicationFont(os.path.dirname(__file__)+'/ui/fonts/Asap-VariableFont_wdth,wght.ttf')
-        self.setFont(QtGui.QFont('Asap', 9))
+        QtGui.QFontDatabase.addApplicationFont(
+            os.path.dirname(__file__) + "/ui/fonts/Asap-VariableFont_wdth,wght.ttf"
+        )
+        font = QtGui.QFont("Asap", 9)
+        font.setStyleStrategy(QtGui.QFont.PreferAntialias)
+        font.setHintingPreference(QtGui.QFont.HintingPreference.PreferNoHinting)
+        self.setFont(font)
 
-        QtCore.QDir.addSearchPath('icons.gui', os.path.dirname(__file__)+'/ui/icons/gui')
+        QtCore.QDir.addSearchPath(
+            "icons.gui", os.path.dirname(__file__) + "/ui/icons/gui"
+        )
 
-        css_file = os.path.dirname(__file__)+'/ui/styles/default/default_style.css'
-        with open(css_file, 'r') as r:
+        css_file = os.path.dirname(__file__) + "/ui/styles/default/default_style.css"
+        with open(css_file, "r") as r:
             self.setStyleSheet(r.read())
-        
-        self.stream_formatter = logging.Formatter("%(name)s - %(levelname)s: %(message)s")
-        self.logger = logging.getLogger('libreflow_launcher')
+
+        self.stream_formatter = logging.Formatter(
+            "%(name)s - %(levelname)s: %(message)s"
+        )
+        self.logger = logging.getLogger("libreflow_launcher")
         self.logger.setLevel(logging.INFO)
 
         self.default_log_handler = logging.StreamHandler(sys.stdout)
@@ -47,45 +55,49 @@ class SessionApp(QtWidgets.QApplication):
 
         self.offline = False
 
-        #Auto start
-        if self.autostart :
+        # Auto start
+        if self.autostart:
             success = self.auto_launch(self.autostart)
             if success:
                 return
-            else :
-                self.log_error(f'Autostart {autostart} libreflow failed')
+            else:
+                self.log_error(f"Autostart {self.autostart} libreflow failed")
 
-        #Check for connection to the api
-        servers = self.ctrl.fetch_servers()
+        # Check for connection to the api
+        self.ctrl.fetch_servers()
         self.ctrl.set_current_host()
-        test_command = self.ctrl.api_get('/versions', json={})
+        try:
+            test_command = self.ctrl.api_get("/versions", json={})
+            if test_command is None:
+                self.offline = True
+        except Exception:
+            self.offline = True
 
         self.view = MainWindow(self.ctrl)
-        
-        self.view.show()
-    
-    def parse_command_line_args(self, args):
-        parser = argparse.ArgumentParser(
-            description='Libreflow Launcher Arguments'
-        )
 
+        self.view.show()
+
+    def parse_command_line_args(self, args):
+        parser = argparse.ArgumentParser(description="Libreflow Launcher Arguments")
+
+        parser.add_argument("-S", "--site", dest="site", help="Site Name to use")
         parser.add_argument(
-            '-S', '--site', dest='site', help='Site Name to use'
-        )
-        parser.add_argument(
-            '--autostart', dest='autostart', help='Skip the launcher if user is assigned to a single project'
+            "--autostart",
+            dest="autostart",
+            help="Skip the launcher if user is assigned to a single project",
         )
 
         values, _ = parser.parse_known_args(args)
 
         if values.site:
-            os.environ['LF_LAUNCHER_SITE_NAME'] = values.site
-        
+            os.environ["LF_LAUNCHER_SITE_NAME"] = values.site
+
         self.autostart = values.autostart
 
-
     def log(self, context, *words):
-        self._log(logging.INFO, ' '.join([str(i) for i in words]), extra={'context': context})
+        self._log(
+            logging.INFO, " ".join([str(i) for i in words]), extra={"context": context}
+        )
 
     def log_info(self, message, *args, **kwargs):
         self._log(logging.INFO, message, *args, **kwargs)
@@ -104,12 +116,11 @@ class SessionApp(QtWidgets.QApplication):
 
     def _log(self, level, message, *args, **kwargs):
         self.logger.log(level, message, *args, **kwargs)
-    
-    def auto_launch(self,project_name):
 
+    def auto_launch(self, project_name):
         servers = self.ctrl.fetch_servers()
 
-        server_uid,project_uid,data = self.ctrl.get_server_from_project(project_name)
+        server_uid, project_uid, data = self.ctrl.get_server_from_project(project_name)
 
         self.ctrl.set_current_host(server_uid)
 
@@ -122,19 +133,23 @@ class SessionApp(QtWidgets.QApplication):
         # Get Remote
         project = self.ctrl.fetch_project(project_name)
 
-        status = project['updated']
+        status = project["updated"]
 
         if not status:
             updated_data = self.ctrl.update_project(project_uid)
             self.log_info(f"Updating {project_name} libreflow")
 
-            data_resolve, env_folder = self.ctrl.update_project_env(project_name, project_uid)
+            data_resolve, env_folder = self.ctrl.update_project_env(
+                project_name, project_uid
+            )
             if data_resolve is None and env_folder is None:
                 return
 
-            updated_data = self.ctrl.update_project(project_uid,updated=True)
+            updated_data = self.ctrl.update_project(project_uid, updated=True)
 
-            update_exec_status = self.ctrl.update_project_exec(project_uid, data_resolve)
+            update_exec_status = self.ctrl.update_project_exec(
+                project_uid, data_resolve
+            )
             if update_exec_status is False:
                 return False
 
@@ -142,16 +157,16 @@ class SessionApp(QtWidgets.QApplication):
         self.log_info(f"Start {project_name} libreflow")
         start_status = self.ctrl.start_project(project_uid, data)
 
-        if not start_status :
+        if not start_status:
             return False
 
         return True
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     if platform.system() == "Windows":
-        myappid = 'lfscoop.libreflow_launcher'
+        myappid = "lfscoop.libreflow_launcher"
         ctypes.windll.shell32.SetCurrentProcessExplicitAppUserModelID(myappid)
-    
+
     app = SessionApp(sys.argv)
-    sys.exit(app.exec_())
\ No newline at end of file
+    sys.exit(app.exec_())
